Index: third_party/npapi/bindings/nptypes.h |
diff --git a/third_party/npapi/bindings/nptypes.h b/third_party/npapi/bindings/nptypes.h |
index e8a139173fcb268d2d963a9fe97b761de78c5e76..300128885cc346745bdba87f871674dcfc5e231a 100644 |
--- a/third_party/npapi/bindings/nptypes.h |
+++ b/third_party/npapi/bindings/nptypes.h |
@@ -40,19 +40,21 @@ |
#define nptypes_h_ |
/* |
* Header file for ensuring that C99 types ([u]int32_t and bool) and |
* true/false macros are available. |
*/ |
#if defined(WIN32) || defined(OS2) |
/* |
- * Win32 and OS/2 don't know C99, so define [u]int_16/32 here. The bool |
+ * Win32 and OS/2 don't know C99, so define [u]int_16/32/64 here. The bool |
* is predefined tho, both in C and C++. |
*/ |
typedef short int16_t; |
typedef unsigned short uint16_t; |
typedef int int32_t; |
typedef unsigned int uint32_t; |
+ typedef long long int64_t; |
+ typedef unsigned long long uint64_t; |
#elif defined(_AIX) || defined(__sun) || defined(__osf__) || defined(IRIX) || defined(HPUX) |
/* |
* AIX and SunOS ship a inttypes.h header that defines [u]int32_t, |
@@ -77,6 +79,7 @@ |
*/ |
#if defined(bsdi) |
typedef u_int32_t uint32_t; |
+ typedef u_int64_t uint64_t; |
#if !defined(__cplusplus) |
typedef int bool; |
@@ -40,19 +40,21 @@ |
#define nptypes_h_ |
/* |
- * Header file for ensuring that C99 types ([u]int32_t and bool) and |
+ * Header file for ensuring that C99 types ([u]int32_t, [u]int64_t and bool) and |
* true/false macros are available. |
*/ |